<?php

/**
 * Questions Controller
 *
 * @link 		https://entusiastics.com
 * @since 		1.0.0
 *
 * @package 	Entusiastics_Quiz_Game
 * @subpackage 	Entusiastics_Quiz_Game/admin/controllers
 */

if( ! defined( 'ABSPATH' ) ) exit;

class QuestionsController {
	
	static function manage() { 

		$action = empty(filter_input(INPUT_GET, 'action')) ? 'list' : filter_input(INPUT_GET, 'action');

		if(empty($action)){
			return false;
		} 

		switch($action) {

			case 'add':
			self :: index();
			break;
			case 'edit': 
			self :: edit();
			break;
			case 'move': 
			self :: move();
			break;
			case 'showTree': 
			self :: showTree();
			break;
			default:
			self :: list_questions();	 
			break;
		}

	}
	
	static function index() {

		$request = filter_input_array(INPUT_POST);
		$quiz_id = intval(filter_input(INPUT_GET, 'quiz_id'));
		$add = filter_input(INPUT_POST, 'ok');
		
		if(!empty($add)) {
			self::add($request, $quiz_id);	
		}

		$_question = new Question();
		$_quiz = new Quiz();
		$_profile = new Profile();

		$quiz = $_quiz->getQuizById($quiz_id);

		// select all profiles for select drop-down
		$profiles = $_profile->getAllProfiles();
		
		// select other questions for the go-to dropdown
		$other_questions = $_question->getQuestionByQuizId($quiz->id);
		
		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH.'admin/partials/entusiastics-quiz-game-question.php');

	} // end add_question


	static function add($request, $quiz_id) {

		$_question = new Question();

		try {

			$new_question_id = $_question->add($request, $quiz_id);

			$_question->save_choices($request, $new_question_id);

			entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-questions&quiz_id=".$quiz_id);

		}
		catch(Exception $e) {
			$error = $e->getMessage();
		}
	}
	
	static function edit() {

		$request = filter_input_array(INPUT_POST);
		$question_id = filter_input(INPUT_GET, 'id');
		$store = filter_input(INPUT_POST, 'ok');
		
		if(!empty($store) and check_admin_referer('entusiastics_quiz_game_question')) {
			self::store($request, $question_id);
		}

		$_question = new Question();
		$_quiz = new Quiz();
		$_choice = new Choice();
		
		// select the quiz and question		
		$question = $_question->getQuestionById($question_id);

		// select the quiz owner
		$quiz = $_quiz->getQuizById($question->quiz_id);

		// select question choices
		$choices = $_choice->getByQuestionId($question->id);
		
		// select other questions for the go-to dropdown
		$other_questions = $_question->getQuestionByQuizId($quiz->id);
		
		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH.'admin/partials/entusiastics-quiz-game-question.php');
		
	} // end edit_quiz

	static function store($request, $question_id) {

		$_question = new Question();

		try {

			$_question->save($request, $question_id);
			$_question->save_choices($request, $question_id);
		}
		catch(Exception $e) {
			$error = $e->getMessage();
		}

	}
	
	// list and delete questions
	static function list_questions() {

		global $wpdb;

		$question_id = filter_input(INPUT_GET, 'id');
		$quiz_id = intval(filter_input(INPUT_GET, 'quiz_id'));
		$delete = filter_input(INPUT_GET, 'del');
		$direcction = filter_input(INPUT_GET, 'dir');
		
		$_question = new Question();
		$_quiz = new Quiz();
		$_profile = new Profile();

		if(!empty($delete)) {
			$_question->delete($question_id);
		}
		
		$quiz = $wpdb->get_row($wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." WHERE id=%d", $quiz_id));

		$questions = $wpdb->get_results($wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_QUESTIONS." WHERE quiz_id=%d ORDER BY sort_order, id", intval($_GET['quiz_id'])));

		$count = count($questions);

		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH."admin/partials/entusiastics-quiz-game-questions.php");

	} // end list_questions

	static function showTree() {
		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH."admin/partials/entusiastics-quiz-game-questions-tree.php");
	}

	static function move($request) {

		global $wpdb;

		$sorted_list = $request['sorted_list'];
		$quiz_id = $request['quiz_id'];

		if(!empty($sorted_list)) {

			foreach ($sorted_list as $key => $question) {

				$result = $wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_QUESTIONS." SET sort_order=%d WHERE id=%d AND quiz_id=%d", $question['sort_order'], $question['id'], $quiz_id));
			}

			if($result === false){
				return -1;
			} else {
				return 1;
			}
		}
	}
}