<?php

/**
 * Profile Model
 *
 *
 * @link       https://entusiastics.com
 * @since      1.0.0
 *
 * @package    Entusiastics_Quiz_Game
 * @subpackage Entusiastics_Quiz_Game/admin/models
 */

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Profile {

	
	function add($vars) {
		
		global $wpdb;
		
		$name = sanitize_text_field($vars['name']);
		$connotation = intval($vars['connotation']);
		$profile_description = sanitize_text_field($vars['profile_description']);
		$image_url = empty($vars['image_url']) ? '' : $vars['image_url'];
		$image_id = empty($vars['image_id']) ? 0 : $vars['image_id'];
		
		$result = $wpdb->query($wpdb->prepare("INSERT INTO ".ENTUSIASTICS_QUIZ_GAME_PROFILES." SET
			name=%s, connotation=%d, profile_description=%s, image_url=%s, image_id=%s", 
			$name, $connotation, $profile_description, $image_url, $image_id));
		
		if($result === false) throw new Exception(__('DB Error', 'entusiastics-quiz-game'));

		return $wpdb->insert_id;	

	} // end add
	
	function save($vars, $id) {

		global $wpdb;
		
		$name = sanitize_text_field($vars['name']);
		$connotation = intval($vars['connotation']);
		$profile_description = sanitize_text_field($vars['profile_description']);
		$image_url = empty($vars['image_url']) ? '' : $vars['image_url'];
		$image_id = empty($vars['image_id']) ? 0 : $vars['image_id'];
		
		$result = $wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_PROFILES." SET
			name=%s, connotation=%d, profile_description=%s, image_url=%s, image_id=%s WHERE id=%d", 
			$name, $connotation, $profile_description, $image_url, $image_id, $id));
		
		if($result === false) throw new Exception(__('DB Error', 'entusiastics-quiz-game'));

		return true;

	} // end save
	
	function delete($profile_id) {

		$result = $this->remove($profile_id);

		entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-profiles");
	}

	function bulkDelete($profiles) {
		
		foreach ($profiles as $profile_id) {
			$this->remove($profile_id);			
		}

		entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-profiles");
	}

	function remove($profile_id) {

		global $wpdb;

		// select the choices
		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_CHOICES." WHERE profile_id=%d", $profile_id);
		$choices = $wpdb->get_row($sql);

		if(!empty($choices)) {
				// update choice with this profile to non profile
			$choices_update = $wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_CHOICES." SET
				profile_id=1 WHERE profile_id=%d", $profile_id));
		}

		// delete profile
		$result = $wpdb->query($wpdb->prepare("DELETE FROM ".ENTUSIASTICS_QUIZ_GAME_PROFILES." WHERE id=%d", $profile_id));

		if($result === false) throw new Exception(__('DB Error', 'entusiastics-quiz-game'));

		return true;
	}

	public function getAllProfiles() {

		global $wpdb;

		$order_by = 'id';

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_PROFILES." ORDER BY %s", $order_by);
		$profiles = $wpdb->get_results($sql);

		return $profiles;
	}

	public function getProfileById($id) {

		global $wpdb;

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_PROFILES." WHERE id=%d", $id);
		$profile = $wpdb->get_row($sql);

		return $profile;
	}

	public function getProfileConnotation($id, $question_id) {

		global $wpdb;

		$sql = $wpdb->prepare("SELECT connotation FROM ".ENTUSIASTICS_QUIZ_GAME_PROFILES." WHERE id=%d AND $question_id=%d", $id, $question_id);
		$connotation = $wpdb->get_row($sql);

		return $connotation;
	}
} 