<?php
/**
 * Globally-accessible functions
 *
 * @link 		https://entusiastics.com
 * @since 		1.0.0
 *
 * @package		Entusiastics_Quiz_Game
 * @subpackage 	Entusiastics_Quiz_Game/includes
 */

/**
 * Get URL where is shortcode latest-quizzes
 */
function entusiastics_quiz_game_get_url_shortcode_landing() {
	global $wpdb;

	$post_id =  $wpdb->get_var("SELECT ID FROM wp_posts WHERE post_content LIKE '%[entusiastics-latest-quizzes]%' AND post_title!='' AND post_status='publish'");

	$url = get_permalink($post_id);

	return $url;
}

/**
 * Get URL where is shortcode single quizz
 */
function entusiastics_quiz_game_get_url_shortcode($quiz_id) {
	global $wpdb;

	$sql =  $wpdb->get_results("SELECT ID FROM {$wpdb->posts} WHERE post_content LIKE '%[entusiastics-quiz-game ".$quiz_id."]%' AND post_status='publish'");
	$post_id = $wpdb->get_var($sql);

	$url = get_permalink($post_id);

	return $url;
}


/**
 * Parse time format 00:00:00 to h m s
 */
function entusiastics_quiz_game_parse_time($time) {

	preg_match("/([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2})/", $time, $result);
	$hour = intval($result[1]);
	$min = intval($result[2]);
	$seconds = intval($result[3]);

	$string = '';

	if($hour != '0') {
		$string = $hour.__('h','entusiastics-quiz-game');
	}

	if($min != '0') {

		if($hour == '0') {
			$string = $string.$min.__('m','entusiastics-quiz-game');
		}else {
			$string = $string.$min.__('m','entusiastics-quiz-game');
		}
	}

	if($seconds != '0') {

		if($hour != '0' || $min != '0') {

			$string = $string.$seconds.__('s','entusiastics-quiz-game');

		} else {

			$string = $seconds.__('s','entusiastics-quiz-game');
		}
		
	}

	return $string;
}

function fix_sort_order_global() {
	
	global $wpdb;

	$quizzes = $wpdb->get_results("SELECT id FROM ".ENTUSIASTICS_QUIZ_GAME_QUIZZES);

	foreach($quizzes as $quiz) {

		$min_id = $wpdb->get_var($wpdb->prepare("SELECT MIN(id) FROM ".ENTUSIASTICS_QUIZ_GAME_QUESTIONS." WHERE quiz_id=%d", $quiz->id));

		$min_id--;

		$wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_QUESTIONS." SET
			sort_order=id-%d WHERE quiz_id=%d", $min_id, $quiz->id));
	}
}	

/**
 * safe redirect
 */
function entusiastics_quiz_game_redirect($url) {
	echo "<meta http-equiv='refresh' content='0;url=$url' />"; 
	exit;
}

/**
* function to conditionally add DB fields
*/
function entusiastics_quiz_game_add_db_fields($fields, $table) {
	global $wpdb;

	// check fields
	$table_fields = $wpdb->get_results("SHOW COLUMNS FROM `$table`");
	$table_field_names = array();
	foreach($table_fields as $f) $table_field_names[] = $f->Field;		
	$fields_to_add=array();

	foreach($fields as $field) {
		if(!in_array($field['name'], $table_field_names)) {
			$fields_to_add[] = $field;
		} 
	}

	// now if there are fields to add, run the query
	if(!empty($fields_to_add)) {
		$sql = "ALTER TABLE `$table` ";

		foreach($fields_to_add as $cnt => $field) {
			if($cnt > 0) $sql .= ", ";
			$sql .= "ADD $field[name] $field[type]";
		} 

		$wpdb->query($sql);
	}
}

/**
 * makes sure all values in array are ints. Typically used to sanitize POST data from multiple checkboxes
 */
function entusiastics_quiz_game_int_array($value) {

	if(empty($value) or !is_array($value)) return array();
	
	$value = array_filter($value, 'is_numeric');

	return $value;
}

/**
 * function to eventually encrypt user's IP address if GDPR features are enabled
 */
function entusiastics_quiz_game_user_ip() {
	if(get_option('entusiastics_quiz_game_gdpr_ips') == 1) {
		$part1 = substr($_SERVER['REMOTE_ADDR'], 0, 8);
		$part2 = substr($_SERVER['REMOTE_ADDR'], 8, strlen($_SERVER['REMOTE_ADDR']));
		$part2 = md5($part2);
		return $part1.$part2;
	}
	
	// no GDPR features
	return $_SERVER['REMOTE_ADDR'];
}

/**
 * Returns the result of the get_max global function
 */
function entusiastics_quiz_game_get_max( $array ) {

	return Entusiastics_Quiz_Game_Globals::get_max( $array );

}

/**
 * Returns the result of the get_svg global function
 */
function entusiastics_quiz_game_get_svg( $svg ) {

	return Entusiastics_Quiz_Game_Globals::get_svg( $svg );

}

/**
 * Returns the result of the get_template global function
 */
function entusiastics_quiz_game_get_template( $name ) {

	return Entusiastics_Quiz_Game_Globals::get_template( $name );

}

class Entusiastics_Quiz_Game_Globals {

	/**
	 * Returns the count of the largest arrays
	 *
	 * @param 		array 		$array 		An array of arrays to count
	 * @return 		int 					The count of the largest array
	 */
	public static function get_max( $array ) {

		if ( empty( $array ) ) { return '$array is empty!'; }

		$count = array();

		foreach ( $array as $name => $field ) {

			$count[$name] = count( $field );

		} //

		$count = max( $count );

		return $count;

 	} // get_max()

 	/**
 	 * Returns the requested SVG.
 	 *
 	 * @param 		string 		$svg 		The name of an SVG
 	 * @return 		mixed 					The SVG code
 	 */
 	public static function get_svg( $svg ) {

 		$return = '';

 		switch ( $svg ) {

 			case 'drag': $return = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" class="drag" height="20px" width="20px"><path d="M19.7 10.5l-2.8 2.8c-.1.1-.3.2-.5.2-.4 0-.7-.3-.7-.7v-1.4h-4.3v4.3h1.4c.4 0 .7.3.7.7 0 .2-.1.4-.2.5l-2.8 2.8c-.1.1-.3.2-.5.2s-.4-.1-.5-.2l-2.8-2.8c-.1-.1-.2-.3-.2-.5 0-.4.3-.7.7-.7h1.4v-4.3H4.3v1.4c0 .4-.3.7-.7.7-.2 0-.4-.1-.5-.2L.3 10.5c-.1-.1-.2-.3-.2-.5s.1-.4.2-.5l2.8-2.8c.1-.1.3-.2.5-.2.4 0 .7.3.7.7v1.4h4.3V4.3H7.2c-.4 0-.7-.3-.7-.7 0-.2.1-.4.2-.5L9.5.3c.1-.1.3-.2.5-.2s.4.1.5.2l2.8 2.8c.1.1.2.3.2.5 0 .4-.3.7-.7.7h-1.4v4.3h4.3V7.2c0-.4.3-.7.7-.7.2 0 .4.1.5.2l2.8 2.8c.1.1.2.3.2.5s0 .4-.2.5z"/></svg>'; break;

		} // switch

		return $return;

 	} // get_svg()

 	/**
	 * Returns the path to a template file
	 *
	 * Looks for the file in these directories, in this order:
	 * 		Current theme
	 * 		Parent theme
	 * 		Current theme templates folder
	 * 		Parent theme templates folder
	 * 		This plugin
	 *
	 * To use a custom list template in a theme, copy the
	 * file from public/templates into a templates folder in your
	 * theme. Customize as needed, but keep the file name as-is. The
	 * plugin will automatically use your custom template file instead
	 * of the ones included in the plugin.
	 *
	 * @param 	string 		$name 			The name of a template file
	 * @return 	string 						The path to the template
	 */
 	public static function get_template( $name ) {

 		$template = '';

 		$locations[] = "{$name}.php";
 		$locations[] = "/templates/{$name}.php";

		/**
		 * Filter the locations to search for a template file
		 *
		 * @param 	array 		$locations 			File names and/or paths to check
		 */
		apply_filters( 'entusiastics-quiz-game-template-paths', $locations );

		$template = locate_template( $locations, TRUE );

		if ( empty( $template ) ) {

			$template = plugin_dir_path( dirname( __FILE__ ) ) . 'public/templates/' . $name . '.php';

		}

		return $template;

 	} // get_template()

} // class
